<?php

namespace Litecms\Currency\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Litecms\Currency\Actions\CurrencyAction;
use Litecms\Currency\Http\Requests\CurrencyActionRequest;
use Litecms\Currency\Http\Resources\CurrencyResource;
use Litecms\Currency\Models\Currency;

/**
 * Admin web controller class.
 */
class CurrencyActionController extends BaseController
{

    /**
     * Action controller function for currency.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(CurrencyActionRequest $request, Currency $currency, $action)
    {
        try {
            $request = $request->all();
            $currency = CurrencyAction::run($action, $currency, $request);

            $data = new CurrencyResource($currency);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('currency::currency.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('currency/currency/' . $currency->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('currency/currency/' . $currency->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
