<?php

namespace Litecms\Currency\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Currency\Events\CurrencyAction as CurrencyActionEvent;
use Litecms\Currency\Notifications\CurrencyAction as CurrencyActionNotification;
use Litepie\Actions\Concerns\AsAction;

class CurrencyAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the CurrencyActionEvent.
     *
     * @param   CurrencyActionEvent  $event
     * @return mixed
     */
    public function handle(CurrencyActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $currency.
     *
     * @param   CurrencyActionEvent  $event
     * @return void
     */
    public function create(CurrencyActionEvent $event)
    {
        $client = $event->currency->client;
        Notification::send($client, new CurrencyActionNotification($event));
    }

    /**
     * Handle the CurrencyActionEvent as a listener.
     *
     * @param   CurrencyActionEvent  $event
     * @return mixed
     */
    public function asListener(CurrencyActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   CurrencyActionEvent  $event
     * @return bool
     */
    private function isAllowed(CurrencyActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
