<?php

namespace Litecms\Currency\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Litecms\Currency\Models\Currency;

class CurrencyPolicy
{

    use CurrencyAction;

    /**
     * Determine if the given user can view the currency.
     *
     * @param Authenticatable $user
     * @param Currency $currency
     *
     * @return bool
     */
    public function view(Authenticatable $user, Currency $currency)
    {
        if ($authUser->canDo('currency.currency.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $currency->is_owner;
    }

    /**
     * Determine if the given user can create a currency.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('currency.currency.create');
    }

    /**
     * Determine if the given user can update the given currency.
     *
     * @param Authenticatable $user
     * @param Currency $currency
     *
     * @return bool
     */
    public function update(Authenticatable $user, Currency $currency)
    {
        if ($user->canDo('currency.currency.edit') && $user->isAdmin()) {
            return true;
        }

        return $currency->is_owner;
    }

    /**
     * Determine if the given user can delete the given currency.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Currency $currency)
    {
        return $currency->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
